@@ -36,20 +36,20 @@ Callback = Union[
 JsonSchemaType = Literal["string", "number", "boolean", "object", "array"]
 
 
-class JsonBaseSchema(TypedDict, total=False):
-    key: str
-    title: str
-    description: str
-    required: bool
-    readonly: bool
-    placeholder: str
-    hidden: bool
-    group: str
-    defaultValue: Union[str, int, bool]
+class JsonBaseSchema(TypedDict):
+    key: NotRequired[Optional[str]]
+    title: NotRequired[Optional[str]]
+    description: NotRequired[Optional[str]]
+    required: NotRequired[Optional[bool]]
+    readonly: NotRequired[Optional[bool]]
+    placeholder: NotRequired[Optional[str]]
+    hidden: NotRequired[Optional[bool]]
+    group: NotRequired[Optional[str]]
+    defaultValue: NotRequired[Optional[Union[str, int, bool]]]
 
 
-class PluginJsonBaseSchema(JsonBaseSchema, total=False):
-    store: bool
+class PluginJsonBaseSchema(JsonBaseSchema):
+    store: NotRequired[Optional[bool]]
     onSet: NotRequired[Callable[[Any, Any], Awaitable[Union[None, Any]]]]
     onGet: NotRequired[Callable[[], Awaitable[Union[Any, None]]]]
 
@@ -285,16 +285,20 @@ class Camera(BaseCamera):
 # camera device
 class BaseDetection(TypedDict):
     id: NotRequired[str]
-
-
-class MotionDetection(BaseDetection):
-    label: NotRequired[str]
+    label: str
+    timestamp: int
+    confidence: float
     boundingBox: Tuple[int, int, int, int]
+    inputWidth: int
+    inputHeight: int
+    origWidth: int
+    origHeight: int
 
 
-class ObjectDetection(BaseDetection):
-    label: NotRequired[str]
-    boundingBox: Tuple[int, int, int, int]
+class MotionDetection(BaseDetection): ...
+
+
+class ObjectDetection(BaseDetection): ...
 
 
 class BaseStateLight(TypedDict):
@@ -520,6 +524,24 @@ class CameraSource(Protocol):
     async def get_stream_info(self) -> Optional[Dict[str, Any]]: ...
 
 
+class PILResizeOptions(TypedDict):
+    resample: NotRequired[Optional[Image.Resampling]]
+    box: NotRequired[Optional[Tuple[int, int, int, int]]]
+    reducing_gap: NotRequired[Optional[int]]
+
+
+class PILRotateOptions(TypedDict):
+    resample: NotRequired[Image.Resampling]
+    expand: NotRequired[int]
+    center: NotRequired[Tuple[int, int]]
+    translate: NotRequired[Tuple[int, int]]
+    fillcolor: NotRequired[Tuple[int, int, int]]
+
+
+class ImageFormat(TypedDict):
+    format: Literal["rgba", "bgr", "gray"]
+
+
 class ImageCrop(TypedDict):
     top: float
     left: float
@@ -527,17 +549,27 @@ class ImageCrop(TypedDict):
     right: float
 
 
-class ImageResize(TypedDict, total=False):
+class ImageResize(TypedDict):
     width: NotRequired[int]
     height: NotRequired[int]
-    filter: str
+    options: NotRequired[PILResizeOptions]
 
 
-class ImageOptions(TypedDict, total=False):
-    format: str
-    crop: ImageCrop
-    resize: ImageResize
-    rotate: int
+class ImageRotate(TypedDict):
+    angle: int
+    options: NotRequired[PILRotateOptions]
+
+
+class ImageOptions(TypedDict):
+    format: NotRequired[ImageFormat]
+    crop: NotRequired[ImageCrop]
+    resize: NotRequired[ImageResize]
+    rotate: NotRequired[ImageRotate]
+
+
+class ProcessImageRequest(TypedDict):
+    data: bytes
+    options: ImageOptions
 
 
 class IceServer(TypedDict):
@@ -551,6 +583,8 @@ class FrameMetadata(TypedDict):
     frameSize: int
     width: int
     height: int
+    origWidth: int
+    origHeight: int
 
 
 class Frame(TypedDict):
